"""
Constant values
"""

JSON_LINK: str = "https://dl.secondarymetabolites.org/mibig/mibig_json_4.0.tar.gz"
GBK_LINK: str = "https://dl.secondarymetabolites.org/mibig/mibig_gbk_4.0.tar.gz"
FASTA_LINK: str = "https://dl.secondarymetabolites.org/mibig/mibig_prot_seqs_4.0.fasta"
METADATA: str = "mibig_json_4.0.tar.gz"
NUCLEOTIDE: str = "mibig_gbk_4.0.tar.gz"
AA: str = "mibig_prot_seqs_4.0.fasta.gz"
CHUNK_SIZE: int = 10 * 1024
